"""
Recopilación de funciones para el análisis de señales en python
"""



# Primero detectamos si estamos en el proceso de instalación de la 
# librería. La herramienta que utilizamos para generar el paquete
# crea la variable __LABUGR_SETUP__
try:
    __LABUGR_SETUP__
except NameError:
    __LABUGR_SETUP__ = False

# Si no estamos en el setup hay que comprobar que no se intenta 
# importar desde el directorio fuente
if not __LABUGR_SETUP__:
    try:
        from labugr.__config__ import show as show_config
    except ImportError:
        msg = """Error importando labugr: labugr no se puede importar
        mientras estés en el directorio fuente. Por favor, ejecute 
        Python desde otro directorio."""
        raise ImportError(msg)


from .signal import *
from .doc.ayuda import ayuda

import numpy as np
#import matplotlib as plt

from numpy import arange, pi, e

#Creacion de arrays
from numpy import (
	array, zeros, ones, eye, full, asarray, copy, fromfunction,
	arange, linspace, logspace, geomspace, tri)

#Guardando y cargando arrays
from numpy import (
	save, load, fromfile)

#Propiedades del array
from numpy import (
	shape, ndim, size, dtype, real, imag, conj, diag, tril ,triu)

#Funciones trigonométricas (son igual que las de math pero se pueden utilizar en arrays)
from numpy import (
	sin, cos, tan, arcsin, arccos, arctan, hypot, sinh, cosh,
	tanh, arcsinh, arccosh, sinc, arctanh, deg2rad, rad2deg)

#Manipulación de arrays
from numpy import (
    reshape, transpose, concatenate, stack, delete, insert,
    unique, roll)
from numpy import array_split as split

#Funciones matemáticas (abs() y pow() estan incluido)
from numpy import(
    floor, ceil, exp, log, sqrt, sum, gradient, cross, maximum,
    minimum)
from numpy import around as round 


#Algebra lineal
#from numpy.linalg import 

#See masked arrays, y allclose para eliminar e-12



#Iteracion
from numpy import nditer

#Funciones lógicas. All y any substituyen a las built_in para 
#que sean compatibles con numpy arrays (use allclose to compare allrays)
from numpy import (
    all, any, logical_and, logical_or, allclose, isclose,)

from . import fftpack

from labugr.testing.utils import PytestTester
test = PytestTester(__name__)
del PytestTester

excluidos = ['respuestaF', 'signal', 'spectral', 'testing', 'windows',
            'doc','waveforms','dependencias']

__all__ = [s for s in dir() if not ((s in excluidos)or s.startswith('_'))]




"""
Generic test utilities.

"""

from __future__ import division, print_function, absolute_import

import os
import sys


__all__ = ['PytestTester']


class PytestTester(object):
    """
    Pytest test runner entry point.
    """

    def __init__(self, module_name):
        self.module_name = module_name

    def __call__(self, label="fast", verbose=1, extra_argv=None, doctests=False,
                 coverage=False, tests=None):
        import pytest

        module = sys.modules[self.module_name]
        module_path = os.path.abspath(module.__path__[0])

        pytest_args = ['-l']

        if doctests:
            raise ValueError("Doctests not supported")

        if extra_argv:
            pytest_args += list(extra_argv)

        if verbose and int(verbose) > 1:
            pytest_args += ["-" + "v"*(int(verbose)-1)]

        if coverage:
            pytest_args += ["--cov=" + module_path]

        if label == "fast":
            pytest_args += ["-m", "not slow"]
        elif label != "full":
            pytest_args += ["-m", label]

        if tests is None:
            tests = [self.module_name]

        pytest_args += ['--pyargs'] + list(tests)

        try:
            code = pytest.main(pytest_args)
        except SystemExit as exc:
            code = exc.code

        return (code == 0)



from setuptools import setup
import sys, os
if sys.version_info[:2] < (2, 7) or (3, 0) <= sys.version_info[:2] < (3, 4):
    raise RuntimeError("Python version 2.7 or >= 3.4 required.")



# def configuration(parent_package='', top_path=None):
#     from numpy.distutils.misc_util import Configuration
#     config = Configuration(None, parent_package, top_path)
#     config.set_options(ignore_setup_xxx_py=True,
#                        assume_default_configuration=True,
#                        delegate_options_to_subpackages=True,
#                        quiet=True)
#     config.add_subpackage('labugr')

#     return config



def setup_package():

    # # Figure out whether to add ``*_requires = ['numpy']``.
    # # We don't want to do that unconditionally, because we risk updating
    # # an installed numpy which fails too often.  Just if it's not installed, we
    # # may give it a try.  See gh-3379.
    # try:
    #     import numpy, matplotlib
    # except ImportError:  # We do not have numpy installed
    #     build_requires = ['numpy>=1.8.2','matplotlib>=2.0.2']
    # else:
    #     # If we're building a wheel, assume there already exist numpy wheels
    #     # for this platform, so it is safe to add numpy to build requirements.
    #     # See gh-5184.
    #     build_requires = (['numpy>=1.8.2','matplotlib>=2.0.2'] if 'bdist_wheel' in sys.argv[1:]
    #                       else [])
    build_requires = ['numpy>=1.8.2']
    packages = ['labugr.testing','labugr']
    
    metadata = dict(
        name='labugr',
        version='0.1.0.6',
        author='Luis Serra Garcia',
        author_email='lsgarcia@correo.ugr.es',
        url='http://github.com/lserraga/labugr',
        package_data={'':['README.md']},
        scripts=['scripts/remove_build.sh'],
        description='Laboratorio de señales UGR.',
        long_description="open('README.md').read()",
        setup_requires=[],
        install_requires=build_requires,
        packages=packages,
        include_package_data=True,
        python_requires='>=2.7,!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*',
    )

    setup(**metadata)


if __name__ == '__main__':
    setup_package()



from __future__ import division, print_function, absolute_import

import sys


def configuration(parent_package='',top_path=None):
    from numpy.distutils.misc_util import Configuration
    config = Configuration('labugr',parent_package,top_path)
    config.add_subpackage('testing')
    config.add_subpackage('fftpack')
    config.add_subpackage('signal')
    config.add_subpackage('signal.tools')
    config.add_subpackage('doc') 
    config.add_subpackage('dependencias')
    config.add_data_dir('doc')#Importamos la documentacion de las funciones para poder encontrarlas con ayuda()

    config.make_config_py() #con esto generamos __config__ que nos sirve para comprobar que no se importa desde el source dir
    return config

if __name__ == '__main__':
    from numpy.distutils.core import setup
    setup(**configuration(top_path='').todict())
